import 'package:camera/camera.dart';
import 'package:flutter/material.dart';

import 'index.dart';

class ContainerMask extends StatefulWidget {
  final Future<void> initializeControllerFuture;
  final Stream<String> cameraStream;
  final CameraController cameraController;
  final Sink<String> cameraSink;
  final OCRCameraWidget widget;

  const ContainerMask({
    Key? key,
    required this.initializeControllerFuture,
    required this.cameraController,
    required this.cameraStream,
    required this.cameraSink,
    required this.widget,
  }) : super(key: key);

  @override
  _ContainerMaskState createState() => _ContainerMaskState();
}

class _ContainerMaskState extends State<ContainerMask> {
  XFile? _xFileResult;

  @override
  Widget build(BuildContext context) {
    return StreamBuilder<String>(
        stream: widget.cameraStream,
        builder: (context, snapshot) {
          if (snapshot.hasData && snapshot.data!.isNotEmpty) {
            return Positioned(
              left: 0,
              right: 0,
              bottom: 40,
              child: Column(
                children: [
                  Text(
                    widget.widget.questionToConfirmUseByTakenPhoto,
                    style: widget.widget.qtcubtpStyle,
                  ),
                  const SizedBox(height: 16),
                  Row(
                    children: [
                      const SizedBox(width: 24),
                      Expanded(
                        child: GestureDetector(
                          onTap: () {
                            widget.cameraSink.add('');
                          },
                          child: Container(
                            padding: const EdgeInsets.symmetric(vertical: 12),
                            alignment: Alignment.center,
                            decoration: BoxDecoration(
                              color: Colors.white.withOpacity(0.1),
                              borderRadius: BorderRadius.circular(8),
                            ),
                            child: Text(
                              widget.widget.rejectText,
                              style: widget.widget.rtStyle,
                            ),
                          ),
                        ),
                      ),
                      const SizedBox(width: 24),
                      Expanded(
                        child: GestureDetector(
                          onTap: () {
                            widget.widget.onResult(_xFileResult);
                            Navigator.of(context).pop();
                          },
                          child: Container(
                            padding: const EdgeInsets.symmetric(vertical: 12),
                            alignment: Alignment.center,
                            decoration: BoxDecoration(
                              color: Colors.white,
                              borderRadius: BorderRadius.circular(8),
                            ),
                            child: Text(
                              widget.widget.confirmText,
                              style: widget.widget.cStyle,
                            ),
                          ),
                        ),
                      ),
                      const SizedBox(width: 24),
                    ],
                  ),
                ],
              ),
            );
          }

          return Positioned(
            left: 16,
            right: 16,
            bottom: 32,
            child: Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                GestureDetector(
                  onTap: () => _onCaptureImage(),
                  child: widget.widget.takePhotoButton,
                ),
              ],
            ),
          );
        });
  }

  void _onCaptureImage() async {
    // Take the Picture in a try / catch block. If anything goes wrong,
    // catch the error.
    try {
      // Ensure that the camera is initialized.
      await widget.initializeControllerFuture;

      // Attempt to take a picture and get the file `image`
      // where it was saved.
      XFile _xFile = await widget.cameraController.takePicture();
      _xFileResult = _xFile;
      widget.cameraSink.add(_xFile.path);
    } catch (e) {
      // If an error occurs, log the error to the console.
      // ignore: avoid_print
      print(e);
    }
  }
}
